let SessionLoad = 1
let s:so_save = &g:so | let s:siso_save = &g:siso | setg so=0 siso=0 | setl so=-1 siso=-1
let v:this_session=expand("<sfile>:p")
silent only
silent tabonly
cd ~/other/own_github/database-temp
if expand('%') == '' && !&modified && line('$') <= 1 && getline(1) == ''
  let s:wipebuf = bufnr('%')
endif
let s:shortmess_save = &shortmess
if &shortmess =~ 'A'
  set shortmess=aoOA
else
  set shortmess=aoO
endif
badd +1 ~/Projects/util-tempdb/t/temp-sqlite.t
badd +1 ~/Projects/util-tempdb/lib/Database/Temp/Driver/Base.pm
badd +1 ~/Projects/util-tempdb/lib/Database/Temp/Driver/Pg.pm
badd +1 ~/Projects/util-tempdb/lib/Database/Temp/Driver/SQLite.pm
badd +1 ~/Projects/util-tempdb/lib/Database/Temp.pm
badd +1 ~/Projects/util-tempdb/lib/Test/Database/Temp.pm
badd +1 ~/Projects/util-tempdb/t/temp-pg.t
badd +62 ~/Projects/util-tempdb/t/pg-new.t
badd +1 ~/Projects/util-tempdb/t/temp-pg-new.t
badd +3 ~/Projects/util-tempdb/.lvimrc
badd +18 ../env-assert/.lvimrc
argglobal
%argdel
$argadd ~/Projects/util-tempdb/t/temp-sqlite.t
set stal=2
tabnew +setlocal\ bufhidden=wipe
tabrewind
edit ~/Projects/util-tempdb/lib/Database/Temp.pm
let s:save_splitbelow = &splitbelow
let s:save_splitright = &splitright
set splitbelow splitright
wincmd _ | wincmd |
vsplit
wincmd _ | wincmd |
vsplit
wincmd _ | wincmd |
vsplit
3wincmd h
wincmd _ | wincmd |
split
1wincmd k
wincmd w
wincmd w
wincmd w
wincmd w
wincmd _ | wincmd |
split
1wincmd k
wincmd w
let &splitbelow = s:save_splitbelow
let &splitright = s:save_splitright
wincmd t
let s:save_winminheight = &winminheight
let s:save_winminwidth = &winminwidth
set winminheight=0
set winheight=1
set winminwidth=0
set winwidth=1
exe '1resize ' . ((&lines * 43 + 44) / 88)
exe 'vert 1resize ' . ((&columns * 78 + 158) / 317)
exe '2resize ' . ((&lines * 41 + 44) / 88)
exe 'vert 2resize ' . ((&columns * 78 + 158) / 317)
exe 'vert 3resize ' . ((&columns * 79 + 158) / 317)
exe 'vert 4resize ' . ((&columns * 79 + 158) / 317)
exe '5resize ' . ((&lines * 43 + 44) / 88)
exe 'vert 5resize ' . ((&columns * 78 + 158) / 317)
exe '6resize ' . ((&lines * 41 + 44) / 88)
exe 'vert 6resize ' . ((&columns * 78 + 158) / 317)
argglobal
balt ~/Projects/util-tempdb/lib/Database/Temp/Driver/Base.pm
setlocal fdm=manual
setlocal fde=0
setlocal fmr={{{,}}}
setlocal fdi=#
setlocal fdl=0
setlocal fml=1
setlocal fdn=20
setlocal fen
silent! normal! zE
let &fdl = &fdl
let s:l = 1 - ((0 * winheight(0) + 21) / 43)
if s:l < 1 | let s:l = 1 | endif
keepjumps exe s:l
normal! zt
keepjumps 1
normal! 019|
wincmd w
argglobal
if bufexists(fnamemodify("~/Projects/util-tempdb/lib/Database/Temp/Driver/Base.pm", ":p")) | buffer ~/Projects/util-tempdb/lib/Database/Temp/Driver/Base.pm | else | edit ~/Projects/util-tempdb/lib/Database/Temp/Driver/Base.pm | endif
if &buftype ==# 'terminal'
  silent file ~/Projects/util-tempdb/lib/Database/Temp/Driver/Base.pm
endif
balt ~/Projects/util-tempdb/lib/Database/Temp.pm
setlocal fdm=manual
setlocal fde=0
setlocal fmr={{{,}}}
setlocal fdi=#
setlocal fdl=0
setlocal fml=1
setlocal fdn=20
setlocal fen
silent! normal! zE
let &fdl = &fdl
let s:l = 1 - ((0 * winheight(0) + 20) / 41)
if s:l < 1 | let s:l = 1 | endif
keepjumps exe s:l
normal! zt
keepjumps 1
normal! 037|
wincmd w
argglobal
if bufexists(fnamemodify("~/Projects/util-tempdb/lib/Database/Temp/Driver/SQLite.pm", ":p")) | buffer ~/Projects/util-tempdb/lib/Database/Temp/Driver/SQLite.pm | else | edit ~/Projects/util-tempdb/lib/Database/Temp/Driver/SQLite.pm | endif
if &buftype ==# 'terminal'
  silent file ~/Projects/util-tempdb/lib/Database/Temp/Driver/SQLite.pm
endif
balt ~/Projects/util-tempdb/lib/Database/Temp/Driver/Pg.pm
setlocal fdm=manual
setlocal fde=0
setlocal fmr={{{,}}}
setlocal fdi=#
setlocal fdl=0
setlocal fml=1
setlocal fdn=20
setlocal fen
silent! normal! zE
let &fdl = &fdl
let s:l = 101 - ((66 * winheight(0) + 42) / 85)
if s:l < 1 | let s:l = 1 | endif
keepjumps exe s:l
normal! zt
keepjumps 101
normal! 09|
wincmd w
argglobal
if bufexists(fnamemodify("~/Projects/util-tempdb/lib/Database/Temp/Driver/Pg.pm", ":p")) | buffer ~/Projects/util-tempdb/lib/Database/Temp/Driver/Pg.pm | else | edit ~/Projects/util-tempdb/lib/Database/Temp/Driver/Pg.pm | endif
if &buftype ==# 'terminal'
  silent file ~/Projects/util-tempdb/lib/Database/Temp/Driver/Pg.pm
endif
balt ~/Projects/util-tempdb/.lvimrc
setlocal fdm=manual
setlocal fde=0
setlocal fmr={{{,}}}
setlocal fdi=#
setlocal fdl=0
setlocal fml=1
setlocal fdn=20
setlocal fen
silent! normal! zE
let &fdl = &fdl
let s:l = 254 - ((61 * winheight(0) + 42) / 85)
if s:l < 1 | let s:l = 1 | endif
keepjumps exe s:l
normal! zt
keepjumps 254
normal! 05|
wincmd w
argglobal
if bufexists(fnamemodify("~/Projects/util-tempdb/lib/Test/Database/Temp.pm", ":p")) | buffer ~/Projects/util-tempdb/lib/Test/Database/Temp.pm | else | edit ~/Projects/util-tempdb/lib/Test/Database/Temp.pm | endif
if &buftype ==# 'terminal'
  silent file ~/Projects/util-tempdb/lib/Test/Database/Temp.pm
endif
balt ~/Projects/util-tempdb/t/temp-sqlite.t
setlocal fdm=manual
setlocal fde=0
setlocal fmr={{{,}}}
setlocal fdi=#
setlocal fdl=0
setlocal fml=1
setlocal fdn=20
setlocal fen
silent! normal! zE
let &fdl = &fdl
let s:l = 42 - ((25 * winheight(0) + 21) / 43)
if s:l < 1 | let s:l = 1 | endif
keepjumps exe s:l
normal! zt
keepjumps 42
normal! 0
wincmd w
argglobal
if bufexists(fnamemodify("~/Projects/util-tempdb/t/temp-sqlite.t", ":p")) | buffer ~/Projects/util-tempdb/t/temp-sqlite.t | else | edit ~/Projects/util-tempdb/t/temp-sqlite.t | endif
if &buftype ==# 'terminal'
  silent file ~/Projects/util-tempdb/t/temp-sqlite.t
endif
balt ~/Projects/util-tempdb/lib/Test/Database/Temp.pm
setlocal fdm=manual
setlocal fde=0
setlocal fmr={{{,}}}
setlocal fdi=#
setlocal fdl=0
setlocal fml=1
setlocal fdn=20
setlocal fen
silent! normal! zE
let &fdl = &fdl
let s:l = 151 - ((37 * winheight(0) + 20) / 41)
if s:l < 1 | let s:l = 1 | endif
keepjumps exe s:l
normal! zt
keepjumps 151
normal! 0
wincmd w
4wincmd w
exe '1resize ' . ((&lines * 43 + 44) / 88)
exe 'vert 1resize ' . ((&columns * 78 + 158) / 317)
exe '2resize ' . ((&lines * 41 + 44) / 88)
exe 'vert 2resize ' . ((&columns * 78 + 158) / 317)
exe 'vert 3resize ' . ((&columns * 79 + 158) / 317)
exe 'vert 4resize ' . ((&columns * 79 + 158) / 317)
exe '5resize ' . ((&lines * 43 + 44) / 88)
exe 'vert 5resize ' . ((&columns * 78 + 158) / 317)
exe '6resize ' . ((&lines * 41 + 44) / 88)
exe 'vert 6resize ' . ((&columns * 78 + 158) / 317)
tabnext
edit ~/Projects/util-tempdb/t/temp-sqlite.t
let s:save_splitbelow = &splitbelow
let s:save_splitright = &splitright
set splitbelow splitright
wincmd _ | wincmd |
vsplit
wincmd _ | wincmd |
vsplit
2wincmd h
wincmd w
wincmd w
wincmd _ | wincmd |
split
1wincmd k
wincmd w
let &splitbelow = s:save_splitbelow
let &splitright = s:save_splitright
wincmd t
let s:save_winminheight = &winminheight
let s:save_winminwidth = &winminwidth
set winminheight=0
set winheight=1
set winminwidth=0
set winwidth=1
exe 'vert 1resize ' . ((&columns * 105 + 158) / 317)
exe 'vert 2resize ' . ((&columns * 105 + 158) / 317)
exe '3resize ' . ((&lines * 42 + 44) / 88)
exe 'vert 3resize ' . ((&columns * 105 + 158) / 317)
exe '4resize ' . ((&lines * 42 + 44) / 88)
exe 'vert 4resize ' . ((&columns * 105 + 158) / 317)
argglobal
balt ~/Projects/util-tempdb/t/pg-new.t
setlocal fdm=manual
setlocal fde=0
setlocal fmr={{{,}}}
setlocal fdi=#
setlocal fdl=0
setlocal fml=1
setlocal fdn=20
setlocal fen
silent! normal! zE
let &fdl = &fdl
let s:l = 39 - ((22 * winheight(0) + 42) / 85)
if s:l < 1 | let s:l = 1 | endif
keepjumps exe s:l
normal! zt
keepjumps 39
normal! 0
wincmd w
argglobal
if bufexists(fnamemodify("~/Projects/util-tempdb/t/temp-pg-new.t", ":p")) | buffer ~/Projects/util-tempdb/t/temp-pg-new.t | else | edit ~/Projects/util-tempdb/t/temp-pg-new.t | endif
if &buftype ==# 'terminal'
  silent file ~/Projects/util-tempdb/t/temp-pg-new.t
endif
balt ../env-assert/.lvimrc
setlocal fdm=manual
setlocal fde=0
setlocal fmr={{{,}}}
setlocal fdi=#
setlocal fdl=0
setlocal fml=1
setlocal fdn=20
setlocal fen
silent! normal! zE
let &fdl = &fdl
let s:l = 118 - ((54 * winheight(0) + 42) / 85)
if s:l < 1 | let s:l = 1 | endif
keepjumps exe s:l
normal! zt
keepjumps 118
normal! 013|
wincmd w
argglobal
if bufexists(fnamemodify("~/Projects/util-tempdb/.lvimrc", ":p")) | buffer ~/Projects/util-tempdb/.lvimrc | else | edit ~/Projects/util-tempdb/.lvimrc | endif
if &buftype ==# 'terminal'
  silent file ~/Projects/util-tempdb/.lvimrc
endif
balt ~/Projects/util-tempdb/t/temp-pg.t
setlocal fdm=manual
setlocal fde=0
setlocal fmr={{{,}}}
setlocal fdi=#
setlocal fdl=0
setlocal fml=1
setlocal fdn=20
setlocal fen
silent! normal! zE
let &fdl = &fdl
let s:l = 17 - ((16 * winheight(0) + 21) / 42)
if s:l < 1 | let s:l = 1 | endif
keepjumps exe s:l
normal! zt
keepjumps 17
normal! 055|
wincmd w
argglobal
if bufexists(fnamemodify("~/Projects/util-tempdb/t/temp-pg.t", ":p")) | buffer ~/Projects/util-tempdb/t/temp-pg.t | else | edit ~/Projects/util-tempdb/t/temp-pg.t | endif
if &buftype ==# 'terminal'
  silent file ~/Projects/util-tempdb/t/temp-pg.t
endif
balt ~/Projects/util-tempdb/.lvimrc
setlocal fdm=manual
setlocal fde=0
setlocal fmr={{{,}}}
setlocal fdi=#
setlocal fdl=0
setlocal fml=1
setlocal fdn=20
setlocal fen
silent! normal! zE
let &fdl = &fdl
let s:l = 31 - ((30 * winheight(0) + 21) / 42)
if s:l < 1 | let s:l = 1 | endif
keepjumps exe s:l
normal! zt
keepjumps 31
normal! 0
wincmd w
exe 'vert 1resize ' . ((&columns * 105 + 158) / 317)
exe 'vert 2resize ' . ((&columns * 105 + 158) / 317)
exe '3resize ' . ((&lines * 42 + 44) / 88)
exe 'vert 3resize ' . ((&columns * 105 + 158) / 317)
exe '4resize ' . ((&lines * 42 + 44) / 88)
exe 'vert 4resize ' . ((&columns * 105 + 158) / 317)
tabnext 1
set stal=1
if exists('s:wipebuf') && len(win_findbuf(s:wipebuf)) == 0 && getbufvar(s:wipebuf, '&buftype') isnot# 'terminal'
  silent exe 'bwipe ' . s:wipebuf
endif
unlet! s:wipebuf
set winheight=1 winwidth=20
let &shortmess = s:shortmess_save
let &winminheight = s:save_winminheight
let &winminwidth = s:save_winminwidth
let s:sx = expand("<sfile>:p:r")."x.vim"
if filereadable(s:sx)
  exe "source " . fnameescape(s:sx)
endif
let &g:so = s:so_save | let &g:siso = s:siso_save
set hlsearch
doautoall SessionLoadPost
unlet SessionLoad
" vim: set ft=vim :
